@@ -3,7 +3,7 @@
 # Filename: AutoInit_GBase8s.sh
 # Function: Auto install GBase 8s software and auto init database.
 # Write by: liaosnet@gbasedbt.com
-# Version : 1.4.14   update date: 2025-07-03
+# Version : 1.4.15   update date: 2025-08-08
 ##################################################################
 ##### Defind env
 export LANG=C
@@ -110,7 +110,7 @@ fi
 CPUTYPE=$(uname -m)
 SOFTCPU=$(echo "${SOFTPACKNAME}" | awk '
     BEGIN{IGNORECASE=1}
-    {if(/FT|KP9/){print "aarch64";exit}
+    {if(/FT|KP9|aarch64/){print "aarch64";exit}
      else if(/SW/){print "sw64";exit}
      else if(/Loongson/){print "loongarch64";exit}
      else {print "x86_64"}
@@ -139,10 +139,10 @@ _loginfo "Datadir: $DATADIR"
 ##### Get env
 NUMCPU=$(awk '/^processor/{i++}END{printf("%d\n",i)}' /proc/cpuinfo)
 NUMMEM=$(awk '/^MemTotal:/{printf("%d\n",$2/1000)}' /proc/meminfo)
-NUMNODE=1
 if [ -x /usr/bin/lscpu -o -x /usr/sbin/lscpu ]; then 
-  NUMNODE=$(lscpu | awk '/NUMA node(s)/{print $NF}')
+  NUMNODE=$(lscpu | awk '/NUMA node\(s\)/{print $NF}')
 fi
+NUMNODE=${NUMNODE:-1}
 
 if [ x"${USER_INST}" = "xsmall" ]; then
   NUMCPU=1
@@ -290,9 +290,9 @@ chown ${USER_NAME}:${USER_NAME} $INSTALL_DIR 2>/dev/null
 chmod 0755 $INSTALL_DIR 2>/dev/null
 
 # ids_install
-mkdir /${USER_NAME}TMP 2>/dev/null
-chown ${USER_NAME}:${USER_NAME} /${USER_NAME}TMP 2>/dev/null
-chmod 1775 /${USER_NAME}TMP 2>/dev/null
+mkdir /${USER_UPPER}TMP 2>/dev/null
+chown ${USER_NAME}:${USER_NAME} /${USER_UPPER}TMP 2>/dev/null
+chmod 1775 /${USER_UPPER}TMP 2>/dev/null
 mkdir -p ${WORKDIR}/tmp 2>/dev/null
 export IATEMPDIR=${WORKDIR}/tmp
 export LD_LIBRARY_PATH=/usr/lib64:/usr/lib:/lib64:/lib:/lib/x86_64-linux-gnu:/lib/aarch64-linux-gnu:$LD_LIBRARY_PATH
